@@ -6,6 +6,7 @@ from git import Repo
 from flexlate import exc
 from flexlate.adder import Adder
 from flexlate.add_mode import AddMode
+from flexlate.bootstrapper import Bootstrapper
 from flexlate.branch_update import get_flexlate_branch_name
 from flexlate.checker import Checker, CheckResults, CheckResultsRenderable
 from flexlate.config_manager import ConfigManager
@@ -21,9 +22,13 @@ from flexlate.styles import console
 from flexlate.syncer import Syncer
 from flexlate.template.base import Template
 from flexlate.template_data import TemplateData
-from flexlate.transactions.transaction import FlexlateTransaction, TransactionType
+from flexlate.transactions.transaction import (
+    FlexlateTransaction,
+    TransactionType,
+)
 from flexlate.transactions.undoer import Undoer
 from flexlate.update.main import Updater
+from flexlate.user_config_manager import UserConfigManager
 
 log.debug("Flexlate debug logging enabled")
 
@@ -33,6 +38,7 @@ class Flexlate:
         self,
         quiet: bool = False,
         adder: Adder = Adder(),
+        bootstrapper: Bootstrapper = Bootstrapper(),
         checker: Checker = Checker(),
         remover: Remover = Remover(),
         config_manager: ConfigManager = ConfigManager(),
@@ -41,14 +47,16 @@ class Flexlate:
         pusher: Pusher = Pusher(),
         renderer: MultiRenderer = MultiRenderer(),
         syncer: Syncer = Syncer(),
-        updater: Updater = Updater(),
         undoer: Undoer = Undoer(),
+        updater: Updater = Updater(),
+        user_config_manager: UserConfigManager = UserConfigManager(),
     ):
         self.quiet = quiet
         # Let rich handle suppressing output
         console.quiet = quiet
 
         self.adder = adder
+        self.bootstrapper = bootstrapper
         self.checker = checker
         self.remover = remover
         self.config_manager = config_manager
@@ -57,8 +65,9 @@ class Flexlate:
         self.pusher = pusher
         self.renderer = renderer
         self.syncer = syncer
-        self.updater = updater
         self.undoer = undoer
+        self.updater = updater
+        self.user_config_manager = user_config_manager
 
     @simple_output_for_exceptions(exc.GitRepoDirtyException)
     def init_project(
@@ -430,5 +439,71 @@ class Flexlate:
         console.print(CheckResultsRenderable(results=check_results.updates))
         return check_results
 
+    def bootstrap_flexlate_init_from_existing_template(
+        self,
+        template_path: str,
+        path: Path = Path("."),
+        template_version: Optional[str] = None,
+        data: Optional[TemplateData] = None,
+        default_add_mode: AddMode = AddMode.LOCAL,
+        merged_branch_name: str = DEFAULT_MERGED_BRANCH_NAME,
+        template_branch_name: str = DEFAULT_TEMPLATE_BRANCH_NAME,
+        remote: str = "origin",
+        no_input: bool = False,
+    ):
+        transaction = FlexlateTransaction(
+            type=TransactionType.BOOTSTRAP,
+            target=template_path,
+            out_root=path,
+        )
+        template = self.finder.find(template_path, version=template_version)
+        repo = Repo(path)
+        self.bootstrapper.bootstrap_flexlate_init_from_existing_template(
+            repo,
+            template,
+            transaction,
+            target_version=template_version,
+            data=data,
+            default_add_mode=default_add_mode,
+            merged_branch_name=merged_branch_name,
+            template_branch_name=template_branch_name,
+            remote=remote,
+            no_input=no_input,
+        )
+
+    def update_template_source_target_version(
+        self,
+        name: str,
+        target_version: Optional[str] = None,
+        add_mode: Optional[AddMode] = None,
+        project_path: Path = Path("."),
+    ):
+        project_config = self.config_manager.load_project_config(project_path)
+        repo = Repo(project_config.path)
+        add_mode = add_mode or project_config.default_add_mode
+        transaction = FlexlateTransaction(
+            type=TransactionType.UPDATE_TARGET_VERSION,
+            target=name,
+            data=dict(target_version=target_version),
+        )
+
+        self.user_config_manager.update_template_source_target_version(
+            name,
+            target_version,
+            repo,
+            transaction,
+            project_path=project_path,
+            add_mode=add_mode,
+            merged_branch_name=get_flexlate_branch_name(
+                repo, project_config.merged_branch_name
+            ),
+            base_merged_branch_name=project_config.merged_branch_name,
+            template_branch_name=get_flexlate_branch_name(
+                repo, project_config.template_branch_name
+            ),
+            base_template_branch_name=project_config.template_branch_name,
+            remote=project_config.remote,
+            config_manager=self.config_manager,
+        )
+
     # TODO: list template sources, list applied templates
-    # TODO: Update target versions in template sources
