@@ -261,10 +261,15 @@ def test_update_project(
     subdir.mkdir(parents=True)
 
     def assert_root_template_output_is_correct(
-        after_version_update: bool = False, after_data_update: bool = False
+        after_version_update: bool = False,
+        after_data_update: bool = False,
+        target_version: Optional[str] = None,
     ):
         _assert_root_template_output_is_correct(
-            template_source, after_version_update, after_data_update
+            template_source,
+            after_version_update,
+            after_data_update,
+            target_version=target_version,
         )
 
     def assert_subdir_template_output_is_correct(
@@ -312,7 +317,7 @@ def test_update_project(
         fxt.apply_template_and_add(
             template_source.name, data=template_source.input_data, no_input=no_input
         )
-        assert_root_template_output_is_correct()
+        assert_root_template_output_is_correct(target_version=template_source.version_1)
 
         # Add an output of the same template source in a subdirectory
         with change_directory_to(subdir):
@@ -335,24 +340,22 @@ def test_update_project(
                     fxt.update(no_input=True)
                 assert "update did not make any new changes" in str(excinfo.value)
 
-            assert_root_template_output_is_correct()
+            assert_root_template_output_is_correct(
+                target_version=template_source.version_1
+            )
             assert_subdir_template_output_is_correct()
 
             # Now update by just passing new data, should change the output
             # even though the version has not changed
             fxt.update(data=[template_source.update_input_data] * 2, no_input=no_input)
-            assert_root_template_output_is_correct(after_data_update=True)
+            assert_root_template_output_is_correct(
+                after_data_update=True, target_version=template_source.version_1
+            )
             assert_subdir_template_output_is_correct(after_data_update=True)
 
             # Now update the target version
-            # TODO: replace with cli command to update target version once it exists
-            config_path = GENERATED_REPO_DIR / "flexlate.json"
-            config = FlexlateConfig.load(config_path)
-            source = config.template_sources[0]
-            source.target_version = template_source.version_2
-            config.save()
-            stage_and_commit_all(
-                repo, f"Update target version for {template_source.name} to version 2"
+            fxt.update_template_source_target_version(
+                template_source.name, template_source.version_2
             )
 
             # Make changes to update local templates to new version (no-op for remote templates)
@@ -362,7 +365,9 @@ def test_update_project(
             fxt.update(no_input=True)
 
     assert_root_template_output_is_correct(
-        after_version_update=True, after_data_update=True
+        after_version_update=True,
+        after_data_update=True,
+        target_version=template_source.version_2,
     )
     assert_subdir_template_output_is_correct(
         after_version_update=True, after_data_update=True
@@ -376,6 +381,7 @@ def _assert_root_template_output_is_correct(
     template_source: TemplateSourceFixture,
     after_version_update: bool = False,
     after_data_update: bool = False,
+    target_version: Optional[str] = None,
     num_template_sources: int = 1,
     template_source_index: int = 0,
 ):
@@ -402,6 +408,7 @@ def _assert_root_template_output_is_correct(
         expect_applied_template_root=template_source.expect_local_applied_template_path,
         expect_data=input_data,
         version=version,
+        target_version=target_version,
         template_source_type=template_source.type,
         name=template_source.name,
         url=template_source.url,
@@ -421,21 +428,6 @@ def test_update_one_template(
     repo = repo_with_placeholder_committed
     no_input = flexlates.type == FlexlateType.APP
 
-    def assert_root_template_output_is_correct(
-        template_source: TemplateSourceFixture,
-        after_version_update: bool = False,
-        after_data_update: bool = False,
-        num_template_sources: int = 2,
-        template_source_index: int = 0,
-    ):
-        _assert_root_template_output_is_correct(
-            template_source,
-            after_version_update,
-            after_data_update,
-            num_template_sources=num_template_sources,
-            template_source_index=template_source_index,
-        )
-
     non_update_template_source: TemplateSourceFixture = COOKIECUTTER_REMOTE_FIXTURE
     with template_source_with_temp_dir_if_local_template(
         COPIER_LOCAL_FIXTURE
@@ -449,10 +441,11 @@ def test_update_one_template(
                     ts.name, data=ts.input_data, no_input=no_input
                 )
                 num_template_sources = i + 1
-                assert_root_template_output_is_correct(
+                _assert_root_template_output_is_correct(
                     ts,
                     num_template_sources=num_template_sources,
                     template_source_index=i,
+                    target_version=ts.version_1,
                 )
 
             # First update does nothing, because version is at target version
@@ -467,9 +460,16 @@ def test_update_one_template(
                     fxt.update([template_source.name], no_input=True)
                 assert "update did not make any new changes" in str(excinfo.value)
 
-            assert_root_template_output_is_correct(template_source)
-            assert_root_template_output_is_correct(
-                non_update_template_source, template_source_index=1
+            _assert_root_template_output_is_correct(
+                template_source,
+                target_version=template_source.version_1,
+                num_template_sources=2,
+            )
+            _assert_root_template_output_is_correct(
+                non_update_template_source,
+                template_source_index=1,
+                target_version=non_update_template_source.version_1,
+                num_template_sources=2,
             )
 
             # Now update by just passing new data, should change the output
@@ -479,23 +479,23 @@ def test_update_one_template(
                 data=[template_source.update_input_data],
                 no_input=no_input,
             )
-            assert_root_template_output_is_correct(
-                template_source, after_data_update=True
+            _assert_root_template_output_is_correct(
+                template_source,
+                after_data_update=True,
+                target_version=template_source.version_1,
+                num_template_sources=2,
             )
             # Other template unaffected
-            assert_root_template_output_is_correct(
-                non_update_template_source, template_source_index=1
+            _assert_root_template_output_is_correct(
+                non_update_template_source,
+                template_source_index=1,
+                target_version=non_update_template_source.version_1,
+                num_template_sources=2,
             )
 
             # Now update the target version
-            # TODO: replace with cli command to update target version once it exists
-            config_path = GENERATED_REPO_DIR / "flexlate.json"
-            config = FlexlateConfig.load(config_path)
-            source = config.template_sources[0]
-            source.target_version = template_source.version_2
-            config.save()
-            stage_and_commit_all(
-                repo, f"Update target version for {template_source.name} to version 2"
+            fxt.update_template_source_target_version(
+                template_source.name, template_source.version_2
             )
 
             # Make changes to update local templates to new version (no-op for remote templates)
@@ -504,12 +504,19 @@ def test_update_one_template(
             # Now update should go to new version
             fxt.update([template_source.name], no_input=True)
 
-        assert_root_template_output_is_correct(
-            template_source, after_version_update=True, after_data_update=True
+        _assert_root_template_output_is_correct(
+            template_source,
+            after_version_update=True,
+            after_data_update=True,
+            num_template_sources=2,
+            target_version=template_source.version_2,
         )
         # Other template unaffected
-        assert_root_template_output_is_correct(
-            non_update_template_source, template_source_index=1
+        _assert_root_template_output_is_correct(
+            non_update_template_source,
+            template_source_index=1,
+            num_template_sources=2,
+            target_version=non_update_template_source.version_1,
         )
 
         project_config_path = GENERATED_REPO_DIR / "flexlate-project.json"
@@ -957,14 +964,8 @@ def test_check(
         assert_no_templates_need_to_be_updated()
 
         # Now update the target version
-        # TODO: replace with cli command to update target version once it exists
-        config_path = GENERATED_REPO_DIR / "flexlate.json"
-        config = FlexlateConfig.load(config_path)
-        source = config.template_sources[0]
-        source.target_version = template_source.version_2
-        config.save()
-        stage_and_commit_all(
-            repo, f"Update target version for {template_source.name} to version 2"
+        fxt.update_template_source_target_version(
+            template_source.name, template_source.version_2
         )
 
         # Make changes to update local templates to new version (no-op for remote templates)
@@ -973,6 +974,71 @@ def test_check(
         assert_template_needs_to_be_updated()
 
 
+def test_bootstrap(
+    flexlates: FlexlateFixture,
+    repo_with_placeholder_committed: Repo,
+    template_source_with_relative: TemplateSourceFixture,
+):
+    fxt = flexlates.flexlate
+    repo = repo_with_placeholder_committed
+    template_source = template_source_with_relative
+    no_input = flexlates.type == FlexlateType.APP
+
+    with change_directory_to(GENERATED_REPO_DIR):
+        template_source.render_without_flexlate()
+        stage_and_commit_all(
+            repo, f"Render files with {template_source.template_type.value}"
+        )
+        fxt.bootstrap_flexlate_init_from_existing_template(
+            template_source.path,
+            template_version=template_source.version_1,
+            data=template_source.input_data,
+            no_input=no_input,
+        )
+
+        _assert_root_template_output_is_correct(template_source)
+
+        # Make changes to update local templates to new version (no-op for remote templates)
+        template_source.version_migrate_func(template_source.url_or_absolute_path)
+
+        # Should be anle to directly update after bootstrap
+        fxt.update(data=[template_source.update_input_data], no_input=no_input)
+
+        _assert_root_template_output_is_correct(
+            template_source, after_version_update=True, after_data_update=True
+        )
+
+
+def test_update_target_version(
+    flexlates: FlexlateFixture,
+    repo_with_placeholder_committed: Repo,
+    template_source: TemplateSourceFixture,
+):
+    fxt = flexlates.flexlate
+    repo = repo_with_placeholder_committed
+
+    config_path = GENERATED_REPO_DIR / "flexlate.json"
+
+    def assert_target_version_is(version: Optional[str]):
+        config = FlexlateConfig.load(config_path)
+        assert len(config.template_sources) == 1
+        ts = config.template_sources[0]
+        assert ts.target_version == version
+
+    with change_directory_to(GENERATED_REPO_DIR):
+        fxt.init_project()
+        fxt.add_template_source(template_source.path)
+        assert_target_version_is(None)
+        fxt.update_template_source_target_version(
+            template_source.name, target_version=template_source.version_2
+        )
+        assert_target_version_is(template_source.version_2)
+
+    last_commit_message = f"Changed target version for template source {template_source.name} to {template_source.version_2}"
+
+    assert_main_commit_message_matches(repo.commit().message, last_commit_message)
+
+
 @contextlib.contextmanager
 def _checkout_new_branch_that_merges_back(
     repo: Repo, fxt: Flexlate, branch_name: str, delete: bool = True
@@ -1029,6 +1095,7 @@ def _assert_project_files_do_not_exist(
 def _assert_template_sources_config_is_correct(
     config_path: Path = GENERATED_REPO_DIR / "flexlate.json",
     version: str = COOKIECUTTER_REMOTE_VERSION_2,
+    target_version: Optional[str] = None,
     name: str = COOKIECUTTER_REMOTE_NAME,
     url: str = COOKIECUTTER_REMOTE_URL,
     path: str = COOKIECUTTER_REMOTE_DEFAULT_EXPECT_PATH,
@@ -1044,6 +1111,7 @@ def _assert_template_sources_config_is_correct(
     template_source = config.template_sources[template_source_index]
     assert template_source.name == name
     assert template_source.version == version
+    assert template_source.target_version == target_version
     assert template_source.git_url == url
     assert template_source.path == path
     assert (
@@ -1099,6 +1167,7 @@ def _assert_config_is_correct(
     expect_applied_template_root: Path = Path("."),
     expect_data: Optional[CookiecutterRemoteTemplateData] = None,
     version: str = COOKIECUTTER_REMOTE_VERSION_2,
+    target_version: Optional[str] = None,
     template_source_type: TemplateSourceType = TemplateSourceType.COOKIECUTTER_REMOTE,
     name: str = COOKIECUTTER_REMOTE_NAME,
     url: str = COOKIECUTTER_REMOTE_URL,
@@ -1121,6 +1190,7 @@ def _assert_config_is_correct(
     _assert_template_sources_config_is_correct(
         ts_config_path,
         version=version,
+        target_version=target_version,
         name=name,
         url=url,
         path=path,
